CPWindow5::CPWindow5(void)
{
//lxrad automatic generated block start, don't edit below!  
  SetFOwner(this);
  SetClass(wxT("CPWindow"));
  SetName(wxT("window5"));
  SetTag(0);
  SetX(313);
  SetY(173);
  SetWidth(433);
  SetHeight(254);
  SetHint(wxT(""));
  SetEnable(1);
  SetVisible(1);
  SetPopupMenu(NULL);
  SetTitle(wxT("LXRAD Layout"));
  SetOverrideRedirect(0);
  EvOnCreate=EVONCREATE & CPWindow5::_EvOnCreate;
  //checkbox1
  checkbox1.SetFOwner(this);
  checkbox1.SetClass(wxT("CCheckBox"));
  checkbox1.SetName(wxT("checkbox1"));
  checkbox1.SetTag(0);
  checkbox1.SetX(37);
  checkbox1.SetY(18);
  checkbox1.SetWidth(200);
  checkbox1.SetHeight(20);
  checkbox1.SetHint(wxT(""));
  checkbox1.SetEnable(1);
  checkbox1.SetVisible(1);
  checkbox1.SetPopupMenu(NULL);
  checkbox1.SetText(wxT("Open an existing Project"));
  checkbox1.SetCheck(1);
  checkbox1.EvOnCheckBox=EVONCHECKBOX & CPWindow5::checkbox1_EvOnCheckBox;
  CreateChild(&checkbox1);
  //checkbox2
  checkbox2.SetFOwner(this);
  checkbox2.SetClass(wxT("CCheckBox"));
  checkbox2.SetName(wxT("checkbox2"));
  checkbox2.SetTag(0);
  checkbox2.SetX(38);
  checkbox2.SetY(81);
  checkbox2.SetWidth(200);
  checkbox2.SetHeight(20);
  checkbox2.SetHint(wxT(""));
  checkbox2.SetEnable(1);
  checkbox2.SetVisible(1);
  checkbox2.SetPopupMenu(NULL);
  checkbox2.SetText(wxT("New Project"));
  checkbox2.SetCheck(0);
  checkbox2.EvOnCheckBox=EVONCHECKBOX & CPWindow5::checkbox2_EvOnCheckBox;
  CreateChild(&checkbox2);
  //string1
  string1.SetFOwner(this);
  string1.SetClass(wxT("CLabel"));
  string1.SetName(wxT("string1"));
  string1.SetTag(0);
  string1.SetX(40);
  string1.SetY(46);
  string1.SetWidth(101);
  string1.SetHeight(20);
  string1.SetHint(wxT(""));
  string1.SetEnable(1);
  string1.SetVisible(1);
  string1.SetPopupMenu(NULL);
  string1.SetText(wxT("Project File"));
  string1.SetAlign(1);
  CreateChild(&string1);
  //string2
  string2.SetFOwner(this);
  string2.SetClass(wxT("CLabel"));
  string2.SetName(wxT("string2"));
  string2.SetTag(0);
  string2.SetX(40);
  string2.SetY(108);
  string2.SetWidth(100);
  string2.SetHeight(20);
  string2.SetHint(wxT(""));
  string2.SetEnable(1);
  string2.SetVisible(1);
  string2.SetPopupMenu(NULL);
  string2.SetText(wxT("Project Dir "));
  string2.SetAlign(1);
  CreateChild(&string2);
  //string3
  string3.SetFOwner(this);
  string3.SetClass(wxT("CLabel"));
  string3.SetName(wxT("string3"));
  string3.SetTag(0);
  string3.SetX(40);
  string3.SetY(138);
  string3.SetWidth(100);
  string3.SetHeight(20);
  string3.SetHint(wxT(""));
  string3.SetEnable(1);
  string3.SetVisible(1);
  string3.SetPopupMenu(NULL);
  string3.SetText(wxT("Project Name"));
  string3.SetAlign(1);
  CreateChild(&string3);
  //edit1
  edit1.SetFOwner(this);
  edit1.SetClass(wxT("CEdit"));
  edit1.SetName(wxT("edit1"));
  edit1.SetTag(0);
  edit1.SetX(144);
  edit1.SetY(43);
  edit1.SetWidth(200);
  edit1.SetHeight(26);
  edit1.SetHint(wxT(""));
  edit1.SetEnable(1);
  edit1.SetVisible(1);
  edit1.SetPopupMenu(NULL);
  edit1.SetText(wxT("/untitled.prj_lxrad"));
  edit1.SetReadOnly(0);
  CreateChild(&edit1);
  //edit2
  edit2.SetFOwner(this);
  edit2.SetClass(wxT("CEdit"));
  edit2.SetName(wxT("edit2"));
  edit2.SetTag(0);
  edit2.SetX(144);
  edit2.SetY(105);
  edit2.SetWidth(200);
  edit2.SetHeight(26);
  edit2.SetHint(wxT(""));
  edit2.SetEnable(0);
  edit2.SetVisible(1);
  edit2.SetPopupMenu(NULL);
  edit2.SetText(wxT(""));
  edit2.SetReadOnly(0);
  CreateChild(&edit2);
  //edit3
  edit3.SetFOwner(this);
  edit3.SetClass(wxT("CEdit"));
  edit3.SetName(wxT("edit3"));
  edit3.SetTag(0);
  edit3.SetX(144);
  edit3.SetY(134);
  edit3.SetWidth(200);
  edit3.SetHeight(26);
  edit3.SetHint(wxT(""));
  edit3.SetEnable(0);
  edit3.SetVisible(1);
  edit3.SetPopupMenu(NULL);
  edit3.SetText(wxT("untitled"));
  edit3.SetReadOnly(0);
  CreateChild(&edit3);
  //button1
  button1.SetFOwner(this);
  button1.SetClass(wxT("CButton"));
  button1.SetName(wxT("button1"));
  button1.SetTag(0);
  button1.SetX(351);
  button1.SetY(43);
  button1.SetWidth(65);
  button1.SetHeight(28);
  button1.SetHint(wxT(""));
  button1.SetEnable(1);
  button1.SetVisible(1);
  button1.SetPopupMenu(NULL);
  button1.EvMouseButtonRelease=EVMOUSEBUTTONRELEASE & CPWindow5::button1_EvMouseButtonRelease;
  button1.SetText(wxT("Choose"));
  CreateChild(&button1);
  //button2
  button2.SetFOwner(this);
  button2.SetClass(wxT("CButton"));
  button2.SetName(wxT("button2"));
  button2.SetTag(0);
  button2.SetX(351);
  button2.SetY(105);
  button2.SetWidth(65);
  button2.SetHeight(28);
  button2.SetHint(wxT(""));
  button2.SetEnable(0);
  button2.SetVisible(1);
  button2.SetPopupMenu(NULL);
  button2.EvMouseButtonRelease=EVMOUSEBUTTONRELEASE & CPWindow5::button2_EvMouseButtonRelease;
  button2.SetText(wxT("Choose"));
  CreateChild(&button2);
  //button3
  button3.SetFOwner(this);
  button3.SetClass(wxT("CButton"));
  button3.SetName(wxT("button3"));
  button3.SetTag(0);
  button3.SetX(156);
  button3.SetY(174);
  button3.SetWidth(65);
  button3.SetHeight(28);
  button3.SetHint(wxT(""));
  button3.SetEnable(1);
  button3.SetVisible(1);
  button3.SetPopupMenu(NULL);
  button3.EvMouseButtonRelease=EVMOUSEBUTTONRELEASE & CPWindow5::button3_EvMouseButtonRelease;
  button3.SetText(wxT("Ok"));
  CreateChild(&button3);
  //button4
  button4.SetFOwner(this);
  button4.SetClass(wxT("CButton"));
  button4.SetName(wxT("button4"));
  button4.SetTag(0);
  button4.SetX(241);
  button4.SetY(173);
  button4.SetWidth(65);
  button4.SetHeight(28);
  button4.SetHint(wxT(""));
  button4.SetEnable(1);
  button4.SetVisible(1);
  button4.SetPopupMenu(NULL);
  button4.EvMouseButtonRelease=EVMOUSEBUTTONRELEASE & CPWindow5::button4_EvMouseButtonRelease;
  button4.SetText(wxT("Cancel"));
  CreateChild(&button4);
  //filedialog1
  filedialog1.SetFOwner(this);
  filedialog1.SetClass(wxT("CFileDialog"));
  filedialog1.SetName(wxT("filedialog1"));
  filedialog1.SetTag(0);
  filedialog1.SetFileName(wxT("untitled.txt"));
  filedialog1.SetFilter(wxT("LXRAD Project (*.prj_lxrad)|*.prj_lxrad|All Files (*.*)|*.*"));
  filedialog1.SetType(129);
  filedialog1.EvOnClose = EVONCLOSE &CPWindow5::Filedialog1OnClose;
  CreateChild(&filedialog1);
  //dirdialog1
  dirdialog1.SetFOwner(this);
  dirdialog1.SetClass(wxT("CDirDialog"));
  dirdialog1.SetName(wxT("dirdialog1"));
  dirdialog1.SetTag(0);
  dirdialog1.EvOnClose = EVONCLOSE &CPWindow5::Dirdialog1OnClose;
  CreateChild(&dirdialog1);
  /*#Others*/
//lxrad automatic generated block end, don't edit above!
};
